<?php
if (!defined('ABSPATH')){
	require "../../../../wp-load.php";
}
require_once(ABSPATH . 'wp-admin/includes/media.php');
require_once(ABSPATH . 'wp-admin/includes/file.php');
require_once(ABSPATH . 'wp-admin/includes/image.php');

if (class_exists('Mtnft_API_Helper') != true) {
    class Mtnft_API_Helper {
        const VERSION = '1.0';

		public function style_post_content( $content )
		{
			if( $content != "" ){
				return wpautop( $content );
			}

			return $content;
		}

		protected function set_categories( $post_id=0, $classification='' )
		{
			if( trim($classification) == "" ){
				return false;
			}
			wp_insert_term( 'red', 'pa_traits' );

			$categs = explode( "/", $classification );
			if( count($categs) > 0 ) {
				foreach ($categs as $categ ) {
					// Add the category
		    		wp_set_object_terms( $post_id, ucfirst($categ), 'product_cat', true );
				}
			}
		}


		protected function set_product_images( $post_id=0, $previews=array() )
		{
			if( count($previews) > 0 ){
				$prod_gallery = array();
				foreach ($previews as $key => $thumb_url) {
					//if( $key)

					if ( ! empty($thumb_url) ) {

			            // download file to temp location
			            $tmp = download_url( $thumb_url );
			            // fix file filename for query strings
			            //preg_match('/[^\?]+\.(jpg|JPG|jpe|JPE|jpeg|JPEG|gif|GIF|png|PNG)/', $thumb_url, $matches);
			            $file_array['name'] = basename($thumb_url.'.png');
			            $file_array['tmp_name'] = $tmp;

			            // if error storing temporarily, unlink
			            if ( is_wp_error( $tmp ) ) {
			                unlink($file_array['tmp_name']);
			                $file_array['tmp_name'] = '';
			            }
			            // do the validation and storage stuff
			            $thumbid = media_handle_sideload( $file_array, $post_id, '' );

						// If error storing permanently, unlink
			            if ( is_wp_error($thumbid) ) {
			                unlink($file_array['tmp_name']);
			                return $thumbid;
			            }
			        }

					if( $key == 'thumbnail' ){
			        	set_post_thumbnail( $post_id, $thumbid );
					}

					$prod_gallery[] = $thumbid;
				}

				update_post_meta( $post_id, "_product_image_gallery", implode(',', $prod_gallery) );
			}
		}

		protected function check_for_duplicate( $product=array() )
		{
			$args = array(
			    'posts_per_page'   	=> -1,
			    'orderby'          	=> 'post_date',
			    'order'            	=> 'DESC',
			    'post_type' 		=> "product",
			    'post_status'      	=> 'publish',
			    'meta_query' => array(
			        array(
			            'key'     => '_sku',
			            'value'   => $product['id'],
			            'compare' => '===',
			        ),
			    ),
			);

			$duplicate_posts = get_posts( $args );
			if( count($duplicate_posts) > 0 && isset($duplicate_posts[0]) ){
				if( isset($duplicate_posts[0]->ID) ){
					return array(
						'status' 	=> 'product_duplicate',
						'post_id'	=> $duplicate_posts[0]->ID
					);
				}
			}

			return array( 'status' => 'new_product' );
		}

		public static function calc_price($price, $decimals = 18) {
			return $price/ pow(10, $decimals);
		}
		public function update_price_batch( $data=array())
		{
			for($i=0; $i< sizeof($data);$i++) {
				$product = $data[$i];
				$this->update_price($product);
			}
			return json_encode(['status' => 'finished', 'current' => sizeof($data)]);
		}

		public function update_price($product) {
			$post_id = wc_get_product_id_by_sku( $product['id']);
			$this->set_price($post_id, $product);
		}

		public function set_price($post_id, $product)
		{
			if(isset($product['sellOrders'])) {
				$priceCrypto = Mtnft_API_Helper::calc_price(explode('.',$product['sellOrders'][0]['currentPrice'])[0] , $product['sellOrders'][0]['paymentTokenContract']['decimals'] ?? 18);
				$priceUSD =  explode('.',$product['sellOrders'][0]['paymentTokenContract']['usdPrice'])[0] * $priceCrypto ;

				update_post_meta( $post_id, '_regular_price',$priceUSD );
				update_post_meta( $post_id, '_sale_price', $priceUSD );
				update_post_meta( $post_id, '_price', $priceUSD);
				update_post_meta( $post_id, '_mtnft_currency_symbol',$product['sellOrders'][0]['paymentTokenContract']['symbol']);
				update_post_meta( $post_id, '_mtnft_currency_name', $product['sellOrders'][0]['paymentTokenContract']['name'] );
				update_post_meta( $post_id, '_mtnft_currency_price', $priceCrypto);
				update_post_meta( $post_id, '_mtnft_currency_image',  $product['sellOrders'][0]['paymentTokenContract']['imageUrl']   );
			} else if (isset($product['lastSale'])) {
				$priceCrypto =  Mtnft_API_Helper::calc_price(explode('.',$product['lastSale']['totalPrice'])[0] , $product['lastSale']['paymentTokenContract']['decimals'] ?? 18);

				$priceUSD =  explode('.',$product['lastSale']['paymentToken']['usdPrice'])[0] * $priceCrypto ;
				update_post_meta( $post_id, '_regular_price',$priceUSD );
				update_post_meta( $post_id, '_sale_price', $priceUSD );
				update_post_meta( $post_id, '_price', $priceUSD);
				update_post_meta( $post_id, '_mtnft_currency_symbol',$product['lastSale']['paymentToken']['symbol']);
				update_post_meta( $post_id, '_mtnft_currency_name', $product['lastSale']['paymentToken']['name'] );
				update_post_meta( $post_id, '_mtnft_currency_price', $priceCrypto);
				update_post_meta( $post_id, '_mtnft_currency_image',  $product['lastSale']['paymentToken']['imageUrl']   );

			} else if(get_option('mtnft')['overridePrice']){
				update_post_meta( $post_id, '_regular_price',get_option('mtnft')['defaultDollars'] );
				update_post_meta( $post_id, '_sale_price', get_option('mtnft')['defaultDollars'] );
				update_post_meta( $post_id, '_price',  get_option('mtnft')['defaultDollars']);
                update_post_meta( $post_id, '_mtnft_currency_name', "ETH" );
                update_post_meta( $post_id, '_mtnft_currency_price',  get_option('mtnft')['defaultETH']);
                update_post_meta( $post_id, '_mtnft_currency_image',  "https://openseauserdata.com/files/6f8e2979d428180222796ff4a33ab929.svg");
			}
		}
		public function add_digital_product( $data=array(), $checkDuplicate = true, $insertNew = true,$postStatus = "publish", $callback= null)
		{
			for($i=0; $i< sizeof($data);$i++) {
				$product = $data[$i];

				if($checkDuplicate) {
					$status = $this->check_for_duplicate( $product );
					if( $status['status'] != 'new_product' ){
						return json_encode(['status' => 'failed', 'current' => sizeof($data)]);
					}
				}

				if(isset(get_option('mtnft')['downloadImages']) && get_option('mtnft')['downloadImages'] == true) {
					$product_images = array();
                    if( isset($product['imageUrl']) ){
                        $product_images['thumbnail'] = $product['imageUrl'];
                    }
                    if( isset($product['imagePreviewUrl']) ){
						$product_images['preview'] = $product['imagePreviewUrl'];
					}
				}

				$post = [];
				$post_id = 0;
				if($insertNew) {
					$post = array(
						'post_author' => get_current_user_id(),
						'post_content' => $product['description'] === null ? '' : $this->style_post_content($product['description']),
						'post_status' => $postStatus,
						'post_title' => $product['name'] ?? '#'.$product['identifier'],
						'post_type' => "product",
					);

					// create the post
					$post_id = wp_insert_post( $post );
				} else {
					$post_id = wc_get_product_id_by_sku( $product['id']);
				}
                if(isset(get_option('mtnft')['downloadImages']) && get_option('mtnft')['downloadImages'] == true) {
                    // set the product thumbnail
                    if (count($product_images) > 0) $this->set_product_images($post_id, $product_images);
                }
                if(isset($product['additionalSettings']['category'])) {
                    wp_set_object_terms( $post_id, $product['additionalSettings']['category'], 'product_cat', true );
                } elseif(isset($product['collection'])){
					wp_insert_term(
						$product['collection'], // the term
						'product_cat', // the taxonomy
						array(
						'slug' => $product['collection']
						)
					);
					wp_set_object_terms( $post_id, $product['collection'], 'product_cat', true );
				}
				wp_set_object_terms( $post_id, 'external', 'product_type' );
				update_post_meta( $post_id, '_mtnft_traits', $product['traits'] );
				update_post_meta( $post_id, '_sku', $product['name'] . '-' . $product['identifier'] );
				update_post_meta( $post_id, '_mtnft_sales', $product['numSales'] );
				update_post_meta( $post_id, '_mtnft_collection', $product['collection'] );
				update_post_meta( $post_id, '_mtnft_thumbnail', $product['imageThumbnailUrl'] );
				update_post_meta( $post_id, '_mtnft_original', $product['imageOriginalUrl'] );
				update_post_meta( $post_id, '_mtnft_preview', $product['imagePreviewUrl'] );
				update_post_meta( $post_id, '_mtnft_fullImg', $product['imageUrl'] );
				update_post_meta( $post_id, '_mtnft_presale', $product['isPresale'] );
				update_post_meta( $post_id, '_mtnft_tokenID', $product['tokenId'] );
				update_post_meta( $post_id, '_product_url', $product['permalink'] );
				update_post_meta( $post_id, '_mtnft_assetContract', $product['assetContract'] );
				update_post_meta( $post_id, '_mtnft_lastSale', $product['lastSale'] );
				update_post_meta( $post_id, '_mtnft_sellOrders', $product['sellOrders']);
				update_post_meta( $post_id, '_mtnft_address', $product['openseaUrl'] );

				if($callback !== null)
					$callback($post_id, $product);

				$this->set_price($post_id, $product);
			}
			return json_encode(['status' => 'finished', 'current' => sizeof($data)]);
		}
	}
}
