<?php
function mtnft_frontend_crypto_price() {
    global $post;
    $symbol = esc_html(get_post_meta(get_the_id($post), '_mtnft_currency_symbol', true));
    $name = esc_html(get_post_meta(get_the_id($post), '_mtnft_currency_name', true));
    $price = esc_html(get_post_meta(get_the_id($post), '_mtnft_currency_price', true));
    $image = esc_html(get_post_meta(get_the_id($post), '_mtnft_currency_image', true));

    echo "
        <div class='nft-importer-alongside nft-importer-crypto-price'>
            <img src='$image' alt='$name' width='10' height='10'/>
            <b class='nft-importer-price'>$price  $symbol</b>
        </div>
    ";
}
add_action( 'woocommerce_before_add_to_cart_form', 'mtnft_frontend_crypto_price' );
add_action( 'woocommerce_after_shop_loop_item', 'mtnft_frontend_crypto_price', 10 );

function mtnft_frontend_add_cart_text($text) {
    global $post;
    if( get_post_meta(get_the_id($post), '_mtnft_currency_name', true)) {

        $presale = get_post_meta(get_the_id($post), '_mtnft_presale', true);

        if($presale) {
            return esc_html__( 'Place bid', 'mtnft' );
        }

        return esc_html__( 'Make offer on Opensea', 'mtnft' );
    }
    return $text;

}

add_filter( 'woocommerce_product_single_add_to_cart_text', 'mtnft_frontend_add_cart_text',11);

function mtnft_override_external_product_url( $url, $product ){
    if ( 'external' === $product->get_type() ) {
        // custom add to cart url example
        if(isset(get_option('mtnft')['referral'])  && get_option('mtnft')['referral'] != '')
            $url = $url."?ref=".get_option('mtnft')['referral'];
        else
            $url;
    }
    return $url;
}

add_filter( 'woocommerce_product_add_to_cart_url', 'mtnft_override_external_product_url', 10, 2 );

function mtnft_frontend() {
    global $post;
    $collectionData = get_post_meta(get_the_id($post), '_mtnft_collection', true);
    if($collectionData !== '') {
        $name = esc_html($collectionData['name']);
        $image = $collectionData['largeImageUrl'] === null ? wc_placeholder_img_src(50,50) : esc_url($collectionData['largeImageUrl']);
        $link = esc_url("https://opensea.io/collection/".$collectionData['slug']);
        $collectionTranslate= esc_html__('Collection', 'mtnft');
        echo "
            <h6 class='nft-importer-last-collection-heading'>$collectionTranslate</h6>
            <a href='$link' target='_blank' class='nft-importer-alongside nft-importer-last-collection'>
                <img src='$image' alt='$name' width='50' height='50' class='nft-importer-avatar'/>
                <span>$name</span>
            </a>
        ";
    }
}
add_action( 'woocommerce_before_add_to_cart_form', 'mtnft_frontend' );

function mtnft_frontend_meta() {
    global $post;
    $presale = esc_html(get_post_meta(get_the_id($post), '_mtnft_presale', true) ? esc_html__('Yes', 'mtnft') : esc_html__('No', 'mtnft'));
    $sales = esc_html(get_post_meta(get_the_id($post), '_mtnft_sales', true) === '' ? 0 : get_post_meta(get_the_id($post), '_mtnft_sales', true));
    $presaleText = esc_html__('Presale', 'mtnft');
    $salesText = esc_html__('Sales', 'mtnft');

    echo "
    <span>$presaleText: <span>$presale</span></span>
    <span>$salesText: <span>$sales</span></span>
    ";
}
add_action( 'woocommerce_product_meta_end', 'mtnft_frontend_meta' );

function mtnft_frontend_sale_tabs( $tabs ) {
    global $post;
	// Adds the new tab
	if(get_post_meta(get_the_id($post), '_mtnft_sellOrders', true) !== '') {
        $tabs['sale_tab'] = array(
            'title' 	=> esc_html__( 'Sell Orders', 'mtnft' ),
            'priority' 	=> 50,
            'callback' 	=> 'mtnft_frontend_sale_tabs_content'
        );
    }
	return $tabs;

}

add_filter( 'woocommerce_product_tabs', 'mtnft_frontend_sale_tabs' );

function mtnft_calc_price($price, $decimals = 18) {
    return $price/ pow(10, $decimals);
}

function mtnft_frontend_sale_tabs_content() {
    global $post;
    $sellOrders = get_post_meta(get_the_id($post), '_mtnft_sellOrders', true);

    if(!$sellOrders || $sellOrders === '') {
        echo esc_html__('No orders yet.','mtnft');
    }
    $user = esc_html__('User', 'mtnft');
    $approvedOnChain = esc_html__('Approved on chain?', 'mtnft');
    $price = esc_html__('Price', 'mtnft');
    $closingOn = esc_html__('Closing on', 'mtnft');

    echo "
    <table style='width:100%;'>
    <tr>
      <th>$user</th>
      <th>$approvedOnChain</th>
      <th>$closingOn</th>
      <th>$price</th>
    </tr>";

    foreach($sellOrders as $order) {
        $orderClosing = date_i18n('l, F jS, Y',$order['closingDate']);
        $approvedOnChain = esc_html($order['approvedOnChain'] ? 'Yes' : 'No');
        $userImage = esc_html($order['maker']['profileImgUrl'] ?? wc_placeholder_img_src(50,50));
        $user = esc_html($order['maker']['address']);
        $priceCRYPTO = esc_html(number_format(mtnft_calc_price(explode('.',$order['currentPrice'])[0] , $order['paymentTokenContract']['decimals'] ?? 18),2));
        $currency = esc_html($order['paymentTokenContract']['symbol']);
        $currencyImage = esc_html($order['paymentTokenContract']['imageUrl']);
        echo "
        <tr>
          <th><img src='$userImage' alt='$user' width='30' height='30' /> $user</th>
          <th>$approvedOnChain</th>
          <th>$orderClosing</th>
          <th><img src='$currencyImage' alt='$currency' width='10' height='10' /> $priceCRYPTO $currency</th>
        </tr>
        ";
    }
    echo "
    </table>
    ";
}

function mtnft_frontend_traits_tabs( $tabs ) {
    global $post;
    $traits = get_post_meta(get_the_id($post), '_mtnft_traits', true);
    if(!isset($traits)) return $tabs;
	// Adds the new tab
    if($traits !== '') {
        if(sizeOf($traits) !== 0) {
            $tabs['traits_tab'] = array(
                'title' 	=> esc_html__( 'Traits', 'mtnft' ),
                'priority' 	=> 50,
                'callback' 	=> 'mtnft_frontend_traits_tabs_content'
            );
        }
    }
	return $tabs;
}

add_filter( 'woocommerce_product_tabs', 'mtnft_frontend_traits_tabs' );

function mtnft_frontend_traits_tabs_content() {
    global $post;

    $traits = get_post_meta(get_the_id($post), '_mtnft_traits', true);
    if(!isset($traits) || !is_array($traits) ) {
        echo esc_html__('No traits.','mtnft');
        return;
    }
    echo "
    <table style='width:100%;'>";

    foreach($traits as $trait) {
        $type = esc_html($trait['traitType']);
        $value = esc_html($trait['value']);
        echo "
        <tr>
          <th>$type</th>
          <th>$value</th>
        </tr>
        ";
    }
    echo "
    </table>
    ";
}
// render styles&js for plugins
function mtnft_enqueue_style() {
    wp_enqueue_style( 'mtnft-default', plugin_dir_url( __FILE__ ).'assets/default.css', false );
}

add_action( 'wp_enqueue_scripts', 'mtnft_enqueue_style' );

/**
 * Change the placeholder image
 */

add_filter('woocommerce_placeholder_img_src', 'mtnft_custom_woocommerce_placeholder_img_src');
function mtnft_custom_woocommerce_placeholder_img_src( $src ) {
    global $post;
    if(is_object($post) && get_post_meta($post->ID, "_mtnft_tokenID")) {
        $external_url = get_post_meta($post->ID, "_mtnft_fullImg");
        if(is_array($external_url) && count($external_url) > 0 && $external_url[0] !== NULL)
            return $external_url[0];

        $external_url = get_post_meta($post->ID, "_mtnft_original");
        if(is_array($external_url) && count($external_url) > 0 && $external_url[0] !== NULL)
            return $external_url[0];

        $external_url = get_post_meta($post->ID, "_mtnft_thumbnail");
        if(is_array($external_url) && count($external_url) > 0  && $external_url[0] !== NULL)
            return $external_url[0];

        $external_url = get_post_meta($post->ID, "_mtnft_preview");
        if((is_array($external_url) && count($external_url) > 0 && $external_url[0] !== NULL))
            return $external_url[0];
    }
    return $src;
}

/*For thumbnail*/
add_filter('woocommerce_placeholder_img', 'mtnft_woocommerce_placeholder_img', 10, 3);
function  mtnft_woocommerce_placeholder_img($image_html, $size, $dimensions){
	$image      = wc_placeholder_img_src( $size );
    global $post;

    //replace image url
	$image_html = '<img src= "'.mtnft_custom_woocommerce_placeholder_img_src($image).'" alt="' . esc_attr($post->post_title) . '" width="' . esc_attr( $dimensions['width'] ) . '" class="woocommerce-placeholder wp-post-image" height="' . esc_attr( $dimensions['height'] ) . '" />';

	return $image_html;
}
